<?PHP
 /**
  * Provides an interface for CLI outputs of museum-digital's dev and admin tools.
  *
  * @author Joshua Ramon Enslin <joshua@museum-digital.de>
  */
 declare(strict_types = 1);

enum MDConsoleStatus {
    case NOTICE;
    case UPDATE;
    case DELETION;
    case ERROR;
    case SKIPPED;

    /**
     * Returns the color for each status.
     *
     * @return string
     */
    public function color():string {

        return match($this) {
            self::NOTICE   => "",
            self::ERROR    => "41", // 0: Red background   | Problem
            self::UPDATE   => "42", // 1: Green background | Edited automatically
            self::DELETION => "44", // 2: Blue background | Deleted
            self::SKIPPED  => "40", // 2: Blue background | Deleted
        };

    }

    /**
     * Returns the color for a CLI command.
     *
     * @return string
     */
    public function get_cli_color():string {

        return match($this) {
            self::NOTICE   => MDConsoleColors::COLOR_OFF,
            self::ERROR    => MDConsoleColors::BG_RED,
            self::UPDATE   => MDConsoleColors::BG_GREEN,
            self::DELETION => MDConsoleColors::BG_BLUE,
            self::SKIPPED  => MDConsoleColors::BG_GREY,
        };

    }

    /**
     * Returns the symbol for each status.
     *
     * @return string
     */
    public function get_symbol():string {

        return match($this) {
            self::SKIPPED => "-",
            self::UPDATE => "U",
            self::ERROR => "E",
            self::DELETION => "D",
            self::NOTICE => "N",
        };

    }
}
